@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Administration Scripts
-# Copyright (c) 2008-2016 Hive Solutions Lda.
+# Copyright (c) 2008-2020 Hive Solutions Lda.
 #
 # This file is part of Hive Administration Scripts.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2016 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2020 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -66,7 +66,7 @@ def pysource_file(file_path, run_pep8 = True, ignores = ()):
     """
 
     try: import pep8
-    except: pep8 = None
+    except ImportError: pep8 = None
 
     if pep8:
         class ErrorReport(pep8.StandardReport):
@@ -221,3 +221,5 @@ def main():
 
 if __name__ == "__main__":
     main()
+else:
+    __path__ = []
