@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Administration Scripts
-# Copyright (c) 2008-2016 Hive Solutions Lda.
+# Copyright (c) 2008-2020 Hive Solutions Lda.
 #
 # This file is part of Hive Administration Scripts.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2016 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2020 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -97,12 +97,11 @@ def remove_trailing_newlines(file_path, windows_newline = True):
         # reverses the file lines
         file_lines.reverse()
 
-        if index == 0:
-            # retrieves the valid file lines
-            valid_file_lines = file_lines
-        else:
-            # retrieves the valid file lines
-            valid_file_lines = file_lines[:index]
+        # in case the original index is set (no extra new lines found)
+        # all the lines are considered valid, otherwise only the valid
+        # (non extra lines) are used as valid
+        if index == 0: valid_file_lines = file_lines
+        else: valid_file_lines = file_lines[:index]
 
         # iterates over all the file lines
         for valid_file_line in valid_file_lines:
@@ -228,18 +227,22 @@ def remove_trailing_spaces_walker(arguments, directory_name, names):
         if file_extensions == None or os.path.split(name)[-1].split(".")[-1] in file_extensions
     ]
 
+    # creates the string based value of the windows newline taking into
+    # account the boolean value of it
+    windows_newline_s = "windows newline" if windows_newline else "unix newline"
+
     # iterates over all the valid complete names with extension filter
     for valid_complete_name in valid_complete_names:
-        # print a message
-        extra.echo("Removing trail in file: %s" % valid_complete_name)
+        # prints a message about the operation to be performed
+        extra.echo("Removing trail in file: %s (%s)" % (valid_complete_name, windows_newline_s))
 
         # removes the trailing spaces for the (path) name
         remove_trailing_spaces(valid_complete_name, tab_to_spaces, windows_newline)
 
         # in case the trailing newlines flag is active
         if trailing_newlines:
-            # prints a message
-            extra.echo("Removing trail newlines in file: %s" % (valid_complete_name,))
+            # prints a message about the operation to be performed
+            extra.echo("Removing trail newlines in file: %s" % valid_complete_name)
 
             # removes the trailing newlines for the(path) name
             remove_trailing_newlines(valid_complete_name, windows_newline)
@@ -386,3 +389,5 @@ def main():
 
 if __name__ == "__main__":
     main()
+else:
+    __path__ = []
