@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Administration Scripts
-# Copyright (c) 2008-2018 Hive Solutions Lda.
+# Copyright (c) 2008-2020 Hive Solutions Lda.
 #
 # This file is part of Hive Administration Scripts.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2018 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2020 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -49,7 +49,6 @@ configurations = (
             "php",
             "cs",
             "java",
-            "kt",
             "cpp",
             "c",
             "m",
@@ -173,7 +172,9 @@ configurations = (
             "sh",
             "drg",
             "am",
-            "m4"
+            "m4",
+            "kt",
+            "asm"
         ),
         "file_exclusion" : ("android-sdk",)
     }
